(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     27105,        772]*)
(*NotebookOutlinePosition[     27933,        800]*)
(*  CellTagsIndexPosition[     27889,        796]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Linear Relations", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell["A package to work with linear relations", "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
Irina Kurbatoba
la_soleil@bk.ru
Department of Applied Mathematics and Mechanics
Voronezh State University
August 2006\
\>", "Subsubtitle",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell["Abstract", "Section",
  PageBreakAbove->True],

Cell[TextData[{
  "This text describes the package",
  StyleBox[" LinearRelations",
    FontWeight->"Bold"],
  " that performs some usual operations with linear relations in ",
  Cell[BoxData[
      \(R\^n\)]],
  ".\n"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  PageBreakAbove->True],

Cell[TextData[{
  "Linear relations is a language [1, 2, 3, 4] that allows one to talk about \
infinitely large linear operators. For example, such operators may arise as \
inverses to not-invertible operators. The main applications of linear \
relations are connected with differential equations of the form F",
  Cell[BoxData[
      \(x\& . \)]],
  "=Gx+f with non-invertible F.\nTo install the package one should copy the \
file LinearRelations.m into the Mathematica's folder \
AddOns\\StandardPackages. After that the following command will load the \
package. "
}], "Text"],

Cell[BoxData[
    \(<< LinearRelations`\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Matrix representation of a relation", "Section",
  PageBreakAbove->True],

Cell[TextData[{
  "We call a ",
  StyleBox["matrix",
    FontSlant->"Italic"],
  " of a linear relation A any basis in the subspacee A in X\[Times]Y. We \
represent such a basis in the form like this"
}], "Text"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"A=\"\>", "\[InvisibleSpace]", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {
                  TagBox[
                    RowBox[{"(", "\[NoBreak]", GridBox[{
                          {"2", "1", "2", "2", "2"},
                          {"2", "1", "2", "2", "2"},
                          {"1", "1", "1", "1", "2"},
                          {"2", "1", "2", "2", "2"}
                          }], "\[NoBreak]", ")"}],
                    Function[ BoxForm`e$, 
                      MatrixForm[ BoxForm`e$]]]},
                {
                  TagBox[
                    RowBox[{"(", "\[NoBreak]", GridBox[{
                          {"1", "1", "0", "2", "0"},
                          {"1", "1", "2", "1", "1"},
                          {"0", "1", "0", "0", "2"},
                          {"2", "2", "2", "2", "2"},
                          {"1", "2", "0", "0", "2"},
                          {"2", "0", "0", "2", "2"},
                          {"2", "0", "1", "0", "2"}
                          }], "\[NoBreak]", ")"}],
                    Function[ BoxForm`e$, 
                      MatrixForm[ BoxForm`e$]]]}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {
            
            MatrixForm[ {{2, 1, 2, 2, 2}, {2, 1, 2, 2, 2}, {1, 1, 1, 1, 2}, {
              2, 1, 2, 2, 2}}], 
            
            MatrixForm[ {{1, 1, 0, 2, 0}, {1, 1, 2, 1, 1}, {0, 1, 0, 0, 2}, {
              2, 2, 2, 2, 2}, {1, 2, 0, 0, 2}, {2, 0, 0, 2, 2}, {2, 0, 1, 0, 
              2}}]}]]}],
      SequenceForm[ "A=", 
        MatrixForm[ {
          
          MatrixForm[ {{2, 1, 2, 2, 2}, {2, 1, 2, 2, 2}, {1, 1, 1, 1, 2}, {2, 
            1, 2, 2, 2}}], 
          
          MatrixForm[ {{1, 1, 0, 2, 0}, {1, 1, 2, 1, 1}, {0, 1, 0, 0, 2}, {2, 
            2, 2, 2, 2}, {1, 2, 0, 0, 2}, {2, 0, 0, 2, 2}, {2, 0, 1, 0, 
            2}}]}]],
      Editable->False]], "Print",
  CellLabel->"From In[506]:="],

Cell["\<\
Here columns form a basis in the subspace A. The upper part of the \
column lies in X, the lower part of the column lies in Y. We keep the matrix \
of a relation in the form {a1,a2}, where a1 and a2 are upper and lower parts \
of the complete matrix A. For example, the above matrix A was created by the \
follown\\ing commands.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{\(nA = \(nB = 5\); m = 4; 
    k = 7;\), "\[IndentingNewLine]", \(a1 = 
        Table[Random[Integer, {1, 2}], {i, m}, {j, 
            nA}];\), "\[IndentingNewLine]", \(a2 = 
        Table[Random[Integer, {0, 2}], {i, k}, {j, 
            nA}];\), "\[IndentingNewLine]", \(a = {a1, 
          a2};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<A=\>\"", ",", 
          RowBox[{
            StyleBox["MatrixFormRelation",
              FontColor->RGBColor[0, 0, 1]], "[", "a", "]"}]}], "]"}], 
      ";"}]}], "Input"],

Cell[TextData[{
  "Here ",
  StyleBox["MatrixFormRelation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " is a command from the package that represents the matrix of a relation in \
a regular way similar to that performed by the standard command MatrixForm.\n\
\nThe matrix representation is not unique. One of possible unified forms is \
the ColomnReduced form similar to that performed by the standard command \
RowReduce. For example,  this creates the ColomnReduced form of the above \
matrix."
}], "Text"],

Cell[BoxData[
    RowBox[{"Print", "[", 
      RowBox[{"\"\<A=\>\"", ",", 
        RowBox[{"MatrixFormRelation", "[", 
          RowBox[{
            StyleBox["ColomnReduceRelation",
              FontColor->RGBColor[0, 0, 1]], "[", "a", "]"}], "]"}]}], 
      "]"}]], "Input"],

Cell[TextData[{
  "The ColomnReduced form is the most close to the usual matrix \
representation of a linear operator. Namely, if the upper part of the matrix \
of a relation is the identity matrix, then the relation is a linear operator \
and the lower part of the matrix is the usual matrix of the operator. If the \
lower part of the matrix of a relation is the identity matrix, then the \
inverse relation (see the definition below) is a linear operator and the \
upper part of the matrix is the matrix of the inverse operator. \n\nThe \
command ",
  StyleBox["MatrixToRelation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " represents a linear operator defined by a matrix A as a linear relation \
defined by the pair of matrices {I,A}, where I is the identity matrix."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Some general relations", "Section",
  PageBreakAbove->True],

Cell[TextData[{
  " The ",
  StyleBox["identity relation",
    FontSlant->"Italic"],
  " corresponds to the identity operator. The identity relation is calculated \
by the command ",
  StyleBox["IdentityRelation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[". \n",
    FontColor->RGBColor[0, 0, 1]],
  " The ",
  StyleBox["zero relation",
    FontSlant->"Italic"],
  " is X\[Times]{0}. The zero relation is calculated by the command ",
  StyleBox["ZeroRelation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[". ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " The ",
  StyleBox["infinite relation ",
    FontSlant->"Italic"],
  "is {0}\[Times]Y. The infinite relation is calculated by the command ",
  StyleBox["InfiniteRelation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[". ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " The",
  StyleBox[" empty relation",
    FontSlant->"Italic"],
  " is {0}\[Times]{0}. The empty relation is calculated by the command ",
  StyleBox["EmptyRelation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[". ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " The ",
  StyleBox["total relation ",
    FontSlant->"Italic"],
  "is X\[Times]Y. The total relation is calculated by the command ",
  StyleBox["TotalRelation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[". \n ",
    FontColor->RGBColor[0, 0, 1]],
  "Here is an example of usage."
}], "Text"],

Cell[BoxData[{\(m = Random[Integer, {1, 9}]; 
    k = Random[Integer, {1, 9}];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<Identity Relation=\>\"", ",", 
          RowBox[{"MatrixFormRelation", "[", 
            RowBox[{
              StyleBox["IdentityRelation",
                FontColor->RGBColor[0, 0, 1]], "[", "m", "]"}], "]"}]}], 
        "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<Zero Relation=\>\"", ",", 
          RowBox[{"MatrixFormRelation", "[", 
            RowBox[{
              StyleBox["ZeroRelation",
                FontColor->RGBColor[0, 0, 1]], "[", \(m, k\), "]"}], "]"}], 
          ",", "\"\<;   Infinite Relation=\>\"", ",", 
          RowBox[{"MatrixFormRelation", "[", 
            RowBox[{
              StyleBox["InfiniteRelation",
                FontColor->RGBColor[0, 0, 1]], "[", \(m, k\), "]"}], "]"}]}], 
        "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<Empty Relation=\>\"", ",", 
          RowBox[{"MatrixFormRelation", "[", 
            RowBox[{
              StyleBox["EmptyRelation",
                FontColor->RGBColor[0, 0, 1]], "[", \(m, k\), "]"}], "]"}], 
          ",", "\"\<;   Total Relation=\>\"", ",", 
          RowBox[{"MatrixFormRelation", "[", 
            RowBox[{
              StyleBox["TotalRelation",
                FontColor->RGBColor[0, 0, 1]], "[", \(m, k\), "]"}], "]"}]}], 
        "]"}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic definitions", "Section",
  PageBreakAbove->True],

Cell[TextData[{
  "Let X and Y be linear spases. A ",
  StyleBox["linear relation ",
    FontSlant->"Italic"],
  "is a linear subspace \[CapitalGamma] in X\[Times]Y. A linear relation \
induces a mutivalued operator A:X\[Rule]Y. Namely, they say that \
y\[Epsilon]Ax or y=Ax iff (x,y)\[Element]\[CapitalGamma]. Usualy, they do not \
distiguish between \[CapitalGamma] and A and write (x,y)\[Element]A instead \
of (x,y)\[Element]\[CapitalGamma].  Any linear operator can be considered as \
a linear relation if one identifies the operator with its graph.\n\nThe",
  StyleBox[" image ",
    FontSlant->"Italic"],
  "of the relation A is the set of all y\[Element]Y such that (x,y)\[Element] \
A for some x\[Element]",
  Cell[BoxData[
      \(X\)]],
  ".\nThe ",
  StyleBox["domain ",
    FontSlant->"Italic"],
  "of the relation A is the set of all x\[Element]X such that (x,y)\[Element] \
A for some y\[Element]Y.\nThe ",
  StyleBox["kernel",
    FontSlant->"Italic"],
  " of the relation A is the set of x\[Epsilon]X such that (x,0)\[Element]A. \
The  kernel is calculated by the command ",
  StyleBox["NullSpaceRelation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  "from the package.\nThe",
  StyleBox[" image of zero ",
    FontSlant->"Italic"],
  "of the relation A is the set of y\[Epsilon]Y such that (0,y)\[Element]A. \
The image of zero is calculated by the command ",
  StyleBox["ImageOfZeroRelation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  "from the package.\nThe",
  StyleBox[" section ",
    FontSlant->"Italic"],
  "of the relation A i",
  StyleBox["s",
    FontSlant->"Italic"],
  " a",
  StyleBox[" ",
    FontSlant->"Italic"],
  "linear operator that defined on the domain of A and maps x into one of y\
\[Epsilon]Ax. Clearly, the section is not uniquely defined. The section is \
calculated by the command ",
  StyleBox["Section",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  "from the package.\n",
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  "Here is an example of usage."
}], "Text"],

Cell[BoxData[{\(nA = Random[Integer, {1, 9}]; m = Random[Integer, {1, 9}]; 
    k = Random[Integer, {1, 9}];\), "\[IndentingNewLine]", \(a1 = 
        Table[Random[Integer, {\(-9\), 9}], {i, m}, {j, 
            nA}];\), "\[IndentingNewLine]", \(a2 = 
        Table[Random[Integer, {\(-9\), 9}], {i, k}, {j, 
            nA}];\), "\[IndentingNewLine]", \(a = {a1, 
          a2};\), "\[IndentingNewLine]", \(Print["\<A:\>" R\^m -> 
        R\^k, "\<;  nA=\>", 
      nA]\), "\[IndentingNewLine]", \(Print["\<A=\>", 
        MatrixFormRelation[a], "\< = \>", 
        MatrixFormRelation[
          ColomnReduceRelation[a]]];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"nullspace", "=", 
        RowBox[{
          StyleBox["NullSpaceRelation",
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0, 1]], "[", "a", "]"}]}], ";"}], "\n", 
    RowBox[{
      RowBox[{"sect", "=", 
        RowBox[{
          StyleBox["Section",
            FontColor->RGBColor[0, 0, 1]], "[", "a", "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"imz", "=", 
        RowBox[{
          StyleBox["ImageOfZeroRelation",
            FontColor->RGBColor[0, 0, 1]], "[", "a", "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<Section of A=\>", 
        MatrixFormRelation[sect], "\<;   Image of Zero of A=\>", 
        MatrixFormRelation[
          imz]];\), "\[IndentingNewLine]", \(Print["\<NullSpace of A=\>", 
        MatrixFormRelation[nullspace]];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["The inverse relation", "Section",
  PageBreakAbove->True],

Cell[TextData[{
  "The ",
  StyleBox["inverse ",
    FontSlant->"Italic"],
  "of the relation A in X\[Times]Y is the relation ",
  Cell[BoxData[
      \(A\^\(-1\)\)]],
  " in Y\[Times]X consisting of all paires (y,x) such that (x,y)\[Element]A. \
The  inverse relation is calculated by the command ",
  StyleBox["InverseRelation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".\n ",
    FontColor->RGBColor[0, 0, 1]],
  "Here is an example of usage."
}], "Text"],

Cell[BoxData[{\(nA = Random[Integer, {1, 9}]; m = Random[Integer, {1, 9}]; 
    k = Random[Integer, {1, 9}];\), "\[IndentingNewLine]", \(a1 = 
        Table[Random[Integer, {\(-9\), 9}], {i, m}, {j, 
            nA}];\), "\[IndentingNewLine]", \(a2 = 
        Table[Random[Integer, {\(-9\), 9}], {i, k}, {j, 
            nA}];\), "\[IndentingNewLine]", \(a = {a1, 
          a2};\), "\[IndentingNewLine]", \(Print["\<A:\>" R\^m -> 
        R\^k, "\<;  nA=\>", nA]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"inv", "=", 
        RowBox[{
          StyleBox["InverseRelation",
            FontColor->RGBColor[0, 0, 1]], "[", "a", "]"}]}], 
      ";"}], "\n", \(Print["\<A=\>", MatrixFormRelation[a], "\< = \>", 
        MatrixFormRelation[
          ColomnReduceRelation[
            a]]];\), "\[IndentingNewLine]", \(Print[\*"\"\<\!\(A\^\(-1\)\)=\>\
\"", MatrixFormRelation[inv], "\< = \>", 
        MatrixFormRelation[ColomnReduceRelation[inv]]];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["The conjugate relation", "Section",
  PageBreakAbove->True],

Cell[TextData[{
  "The",
  StyleBox[" conjugate ",
    FontSlant->"Italic"],
  "of a relation",
  StyleBox[" ",
    FontSlant->"Italic"],
  "A is the relation ",
  Cell[BoxData[
      \(A\^\(\(*\)\(\ \)\)\)]],
  "that consists of pairs (",
  Cell[BoxData[
      \(\(y\^*\), \(x\^*\)\)]],
  ")\[Element]",
  Cell[BoxData[
      \(\(Y\^*\)\[Times]\(X\^*\)\)]],
  "such that <x, ",
  Cell[BoxData[
      \(\(x\^*\)\)]],
  "> = <y,",
  Cell[BoxData[
      \(\(\(\ \)\(y\^*\)\)\)]],
  "> for all pairs (x,y)\[Element]A. The conjugate relation is calculated by \
the command ",
  StyleBox["ConjugateRelation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ".\n",
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  "Here is an example of usage."
}], "Text"],

Cell[BoxData[{\(nA = Random[Integer, {1, 9}]; m = Random[Integer, {1, 9}]; 
    k = Random[Integer, {1, 9}];\), "\[IndentingNewLine]", \(a1 = 
        Table[Random[Integer, {\(-9\), 9}], {i, m}, {j, 
            nA}];\), "\[IndentingNewLine]", \(a2 = 
        Table[Random[Integer, {\(-9\), 9}], {i, k}, {j, 
            nA}];\), "\[IndentingNewLine]", \(a = {a1, 
          a2};\), "\[IndentingNewLine]", \(Print["\<A:\>" R\^m -> 
        R\^k, "\<;  nA=\>", nA]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"conj", "=", 
        RowBox[{
          StyleBox["ConjugateRelation",
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0, 1]], "[", "a", "]"}]}], 
      ";"}], "\n", \(Print["\<A=\>", MatrixFormRelation[a], "\< = \>", 
        MatrixFormRelation[
          ColomnReduceRelation[
            a]]];\), "\[IndentingNewLine]", \(Print["\<Conjugate of A=\>", 
        MatrixFormRelation[conj], "\< = \>", 
        MatrixFormRelation[ColomnReduceRelation[conj]]];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["The sum and harmonic sum of relations", "Section",
  PageBreakAbove->True],

Cell[TextData[{
  "The ",
  StyleBox["sum",
    FontSlant->"Italic"],
  " of the realations ",
  Cell[BoxData[
      \(A\_1\)]],
  " and  ",
  Cell[BoxData[
      \(A\_2\)]],
  " consists of all paires (x, ",
  Cell[BoxData[
      \(y\_1\)]],
  "+",
  Cell[BoxData[
      \(y\_2\)]],
  "), where (x,",
  Cell[BoxData[
      \(y\_1\)]],
  ")\[Element]",
  Cell[BoxData[
      \(A\_1\)]],
  " and (x,",
  Cell[BoxData[
      \(y\_2\)]],
  ")\[Element]",
  Cell[BoxData[
      \(\(\(A\_2\)\(.\)\)\)]],
  " The sum is calculated by the command ",
  StyleBox["Addition",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".",
    FontColor->RGBColor[1, 0, 0]],
  "\n\nThe",
  StyleBox[" harmonic sum",
    FontSlant->"Italic"],
  " of the realations  ",
  Cell[BoxData[
      \(A\_1\)]],
  " and ",
  Cell[BoxData[
      \(A\_2\)]],
  " consists of all paires (",
  Cell[BoxData[
      \(x\_1\)]],
  "+",
  Cell[BoxData[
      \(x\_2\)]],
  ", y), where (",
  Cell[BoxData[
      \(x\_1\)]],
  ",y)\[Element]",
  Cell[BoxData[
      \(A\_1\)]],
  " and (",
  Cell[BoxData[
      \(x\_2\)]],
  ",y)\[Element]",
  Cell[BoxData[
      \(\(\(\ \)\(\(A\_2\)\(.\)\)\)\)]],
  " The harmonic sum is calculated by the command ",
  StyleBox["HarmonicAddition",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".\n",
    FontColor->RGBColor[0, 0, 1]],
  "Here are examples."
}], "Text"],

Cell[BoxData[{\(lengthOfColumn = Random[Integer, {1, 9}]; 
    m = Random[Integer, {1, 9}]; 
    k = Random[Integer, {1, 9}];\), "\[IndentingNewLine]", \(nA = 
        lengthOfColumn;\), "\[IndentingNewLine]", \(nB = 
        lengthOfColumn;\), "\[IndentingNewLine]", \(a1 = 
        Table[Random[Integer, {\(-9\), 9}], {i, m}, {j, 
            nA}];\), "\[IndentingNewLine]", \(a2 = 
        Table[Random[Integer, {\(-9\), 9}], {i, k}, {j, 
            nA}];\), "\[IndentingNewLine]", \(b1 = 
        Table[Random[Integer, {\(-9\), 9}], {i, m}, {j, 
            nB}];\), "\[IndentingNewLine]", \(b2 = 
        Table[Random[Integer, {\(-9\), 9}], {i, k}, {j, 
            nB}];\), "\[IndentingNewLine]", \(a = {a1, a2}; 
    b = {b1, b2};\), "\[IndentingNewLine]", \(Print["\<A,B:\>", 
      R\^m -> R\^k, "\<;  nA=\>", nA, "\<;  nB=\>", nB]; 
    Print["\<B=\>", MatrixFormRelation[b], "\<;  A=\>", 
      MatrixFormRelation[a]];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"fin", "=", 
        RowBox[{
          StyleBox["Addition",
            FontColor->RGBColor[0, 0, 1]], "[", \(a, b\), "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<A+B=\>", 
      MatrixFormRelation[fin], "\< = \>", 
      MatrixFormRelation[ColomnReduceRelation[fin] // N]]\)}], "Input"],

Cell[BoxData[{\(lengthOfColumn = Random[Integer, {1, 9}]; 
    m = Random[Integer, {1, 9}]; 
    k = Random[Integer, {1, 9}];\), "\[IndentingNewLine]", \(nA = 
        lengthOfColumn;\), "\[IndentingNewLine]", \(nB = 
        lengthOfColumn;\), "\[IndentingNewLine]", \(a1 = 
        Table[Random[Integer, {\(-9\), 9}], {i, m}, {j, 
            nA}];\), "\[IndentingNewLine]", \(a2 = 
        Table[Random[Integer, {\(-9\), 9}], {i, k}, {j, 
            nA}];\), "\[IndentingNewLine]", \(b1 = 
        Table[Random[Integer, {\(-9\), 9}], {i, m}, {j, 
            nB}];\), "\[IndentingNewLine]", \(b2 = 
        Table[Random[Integer, {\(-9\), 9}], {i, k}, {j, 
            nB}];\), "\[IndentingNewLine]", \(a = {a1, a2}; 
    b = {b1, b2};\), "\[IndentingNewLine]", \(Print["\<A,B:\>", 
      R\^m -> R\^k, "\<;  nA=\>", nA, "\<;  nB=\>", 
      nB]\), "\[IndentingNewLine]", \(Print["\<B=\>", 
        MatrixFormRelation[b], "\<;  A=\>", 
        MatrixFormRelation[a]];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"fin", "=", 
        RowBox[{
          StyleBox["HarmonicAddition",
            FontColor->RGBColor[0, 0, 1]], "[", \(a, b\), "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<A\[Omega]B=\>", 
      MatrixFormRelation[fin], "\< = \>", 
      MatrixFormRelation[ColomnReduceRelation[fin] // N]]\)}], "Input"],

Cell[BoxData[{\(lengthOfColumn = Random[Integer, {1, 9}]; 
    m = Random[Integer, {1, 9}]; 
    k = Random[Integer, {1, 9}];\), "\[IndentingNewLine]", \(nA = 
        lengthOfColumn;\), "\[IndentingNewLine]", \(nB = 
        lengthOfColumn;\), "\[IndentingNewLine]", \(a1 = 
        Table[Random[Integer, {\(-9\), 9}], {i, m}, {j, 
            nA}];\), "\[IndentingNewLine]", \(a2 = 
        Table[Random[Integer, {\(-9\), 9}], {i, k}, {j, 
            nA}];\), "\[IndentingNewLine]", \(b1 = 
        Table[Random[Integer, {\(-9\), 9}], {i, m}, {j, 
            nB}];\), "\[IndentingNewLine]", \(b2 = 
        Table[Random[Integer, {\(-9\), 9}], {i, k}, {j, 
            nB}];\), "\[IndentingNewLine]", 
    StyleBox[\(Do[b1[\([i, 1]\)] = a1[\([i, 1]\)] + a1[\([i, 2]\)], {i, m}]\),
      
      FontColor->RGBColor[1, 0, 1]], "\[IndentingNewLine]", \(a = {a1, a2}; 
    b = {b1, b2};\), "\[IndentingNewLine]", \(Print["\<A,B:\>" R\^m -> 
        R\^k, "\<;  nA=\>", nA, "\<;  nB=\>", 
      nB]\), "\[IndentingNewLine]", \(Print["\<B=\>", 
        MatrixFormRelation[b], "\< = \>", 
        MatrixFormRelation[ColomnReduceRelation[b]], "\<;  A=\>", 
        MatrixFormRelation[a], "\< = \>", 
        MatrixFormRelation[
          ColomnReduceRelation[a]]];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"fin", "=", 
        RowBox[{
          StyleBox["Addition",
            FontColor->RGBColor[0, 0, 1]], "[", \(a, b\), "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<A+B=\>", 
      MatrixFormRelation[fin], "\< = \>", 
      MatrixFormRelation[ColomnReduceRelation[fin] // N]]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["The product of relations", "Section",
  PageBreakAbove->True],

Cell[TextData[{
  " The",
  StyleBox[" product",
    FontSlant->"Italic"],
  " of relations A and B consisnts of all pairs (x,z) such that (x,y)\
\[Element]B and (y,z)\[Element]A for some y.The product is calculated by the \
command ",
  StyleBox["Multiplication",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  "Here is an example."
}], "Text"],

Cell[BoxData[{\(nA = Random[Integer, {1, 9}]; nB = Random[Integer, {1, 9}]; 
    l = Random[Integer, {1, 9}]; m = Random[Integer, {1, 9}]; 
    k = Random[Integer, {1, 9}];\), "\[IndentingNewLine]", \(a1 = 
        Table[Random[Integer, {\(-9\), 9}], {i, m}, {j, 
            nA}];\), "\[IndentingNewLine]", \(a2 = 
        Table[Random[Integer, {\(-9\), 9}], {i, k}, {j, 
            nA}];\), "\[IndentingNewLine]", \(b2 = 
        Table[Random[Integer, {\(-9\), 9}], {i, m}, {j, 
            nB}];\), "\[IndentingNewLine]", \(b1 = 
        Table[Random[Integer, {\(-9\), 9}], {i, l}, {j, 
            nB}];\), "\[IndentingNewLine]", \(a = {a1, a2}; 
    b = {b1, b2};\), "\[IndentingNewLine]", \(Print["\<B:\>" R\^l -> 
        R\^m, "\<;  A:\>" R\^m -> R\^k, "\<;  nA=\>", nA, "\<;  nB=\>", 
      nB]\), "\[IndentingNewLine]", \(Print["\<B=\>", 
        MatrixFormRelation[b], "\<;  A=\>", 
        MatrixFormRelation[a]];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"fin", "=", 
        RowBox[{
          StyleBox["Multiplication",
            FontColor->RGBColor[0, 0, 1]], "[", \(a, b\), "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<AB=\>", 
        MatrixFormRelation[fin], "\< = \>", 
        MatrixFormRelation[ColomnReduceRelation[fin]]];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Section",
  PageBreakBelow->Automatic],

Cell["\<\
  [1]   Arendt W. Approximation of degenerate semigroups. Tubinger \
Berichte fur Funktionalanalysis. Helf Basel: Birkhauser--Verlag, 2001.
  [2]   Baskakov A. G. and Chernyshov K. I. Spectral theory of linear \
relations and degenerate semigroups of operators. Mathemat. Sbornik, 2002. \
Vol. 371, No~11. pp. 3--42 (in Russian).
  [3]   Cross R. Multivalued linear operators. New York: M. Dekker, 1998.
  [4]   Favini A., Yagi A. Degenerate evolution equations in Banach spaces. \
New York: M. Dekker, 1998.\
\>", "Reference",
  PageBreakBelow->Automatic]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 907}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{1272, 869},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, 9999},
Magnification->1,
StyleDefinitions -> "ArticleClassic.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 82, 2, 84, "Title"],
Cell[1861, 57, 108, 2, 37, "Subtitle"],
Cell[1972, 61, 173, 7, 110, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2170, 72, 51, 1, 56, "Section",
  PageBreakAbove->True],
Cell[2224, 75, 230, 8, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2491, 88, 55, 1, 30, "Section",
  PageBreakAbove->True],
Cell[2549, 91, 579, 11, 61, "Text"],
Cell[3131, 104, 52, 1, 31, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3220, 110, 78, 1, 30, "Section",
  PageBreakAbove->True],
Cell[3301, 113, 212, 6, 27, "Text"],
Cell[3516, 121, 2029, 47, 181, "Print"],
Cell[5548, 170, 399, 8, 44, "Text"],
Cell[5950, 180, 575, 13, 111, "Input"],
Cell[6528, 195, 527, 11, 61, "Text"],
Cell[7058, 208, 277, 7, 31, "Input"],
Cell[7338, 217, 804, 14, 78, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8179, 236, 65, 1, 30, "Section",
  PageBreakAbove->True],
Cell[8247, 239, 1716, 57, 112, "Text"],
Cell[9966, 298, 1538, 35, 91, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11541, 338, 60, 1, 30, "Section",
  PageBreakAbove->True],
Cell[11604, 341, 2220, 61, 163, "Text"],
Cell[13827, 404, 1500, 33, 232, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15364, 442, 63, 1, 30, "Section",
  PageBreakAbove->True],
Cell[15430, 445, 488, 15, 44, "Text"],
Cell[15921, 462, 971, 18, 173, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16929, 485, 65, 1, 30, "Section",
  PageBreakAbove->True],
Cell[16997, 488, 767, 31, 44, "Text"],
Cell[17767, 521, 1008, 19, 172, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18812, 545, 80, 1, 30, "Section",
  PageBreakAbove->True],
Cell[18895, 548, 1412, 68, 78, "Text"],
Cell[20310, 618, 1285, 24, 232, "Input"],
Cell[21598, 644, 1340, 25, 252, "Input"],
Cell[22941, 671, 1614, 31, 292, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[24592, 707, 67, 1, 30, "Section",
  PageBreakAbove->True],
Cell[24662, 710, 462, 15, 44, "Text"],
Cell[25127, 727, 1286, 23, 212, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26450, 755, 58, 1, 30, "Section",
  PageBreakBelow->Automatic],
Cell[26511, 758, 566, 10, 64, "Reference",
  PageBreakBelow->Automatic]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

